"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_general_1 = require("@energyweb/utils-general");
const Registry_json_1 = __importDefault(require("../../build/contracts/Registry.json"));
class Registry extends utils_general_1.GeneralFunctions {
    constructor(web3, address) {
        const buildFile = Registry_json_1.default;
        super(address
            ? new web3.eth.Contract(buildFile.abi, address)
            : new web3.eth.Contract(buildFile.abi, buildFile.networks.length > 0 ? buildFile.networks[0] : null));
        this.web3 = web3;
    }
    async initialize(txParams) {
        const method = this.web3Contract.methods.initialize();
        return this.send(method, txParams);
    }
    async getAllEvents(eventFilter) {
        return this.web3Contract.getPastEvents('allEvents', this.createFilter(eventFilter));
    }
    async getAllTransferSingleEvents(eventFilter) {
        return this.web3Contract.getPastEvents('TransferSingle', this.createFilter(eventFilter));
    }
    async getAllTransferBatchEvents(eventFilter) {
        return this.web3Contract.getPastEvents('TransferBatch', this.createFilter(eventFilter));
    }
    async getAllIssuanceSingleEvents(eventFilter) {
        return this.web3Contract.getPastEvents('IssuanceSingle', this.createFilter(eventFilter));
    }
    async balanceOf(_tokenOwner, _id, txParams) {
        return this.web3Contract.methods.balanceOf(_tokenOwner, _id).call(txParams);
    }
    async claimedBalanceOf(_tokenOwner, _id, txParams) {
        return this.web3Contract.methods.claimedBalanceOf(_tokenOwner, _id).call(txParams);
    }
    async getCertificate(_certificateId, txParams) {
        return this.web3Contract.methods.getCertificate(_certificateId).call(txParams);
    }
    async safeTransferFrom(_from, _to, _certificateId, _value, _data, txParams) {
        const method = this.web3Contract.methods.safeTransferFrom(_from, _to, _certificateId, _value, _data);
        return this.send(method, txParams);
    }
    async safeTransferAndClaimFrom(_from, _to, _certificateId, _value, _data, _claimData, txParams) {
        const method = this.web3Contract.methods.safeTransferAndClaimFrom(_from, _to, _certificateId, _value, _data, _claimData);
        return this.send(method, txParams);
    }
    async safeBatchTransferAndClaimFrom(_from, _to, _ids, _values, _data, _claimData, txParams) {
        const method = this.web3Contract.methods.safeBatchTransferAndClaimFrom(_from, _to, _ids, _values, _data, _claimData);
        return this.send(method, txParams);
    }
    async safeBatchTransferFrom(_from, _to, _ids, _values, _data, txParams) {
        const method = this.web3Contract.methods.safeBatchTransferFrom(_from, _to, _ids, _values, _data);
        return this.send(method, txParams);
    }
    async totalSupply(txParams) {
        return this.web3Contract.methods.totalSupply().call(txParams);
    }
    async issue(_to, _validityData, _topic, _value, _data, txParams) {
        const method = this.web3Contract.methods.issue(_to, _validityData, _topic, _value, _data);
        return this.send(method, txParams);
    }
}
exports.Registry = Registry;
//# sourceMappingURL=Registry.js.map